#
# spec file for package libosip2
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libosip2
Version:        4.1.0
Release:        5.3
Summary:        Implementation of SIP--RFC 3261
License:        LGPL-2.1+
Group:          Productivity/Networking/Other
Url:            http://www.fsf.org/software/osip/osip.html
Source:         http://ftp.gnu.org/gnu/osip/%{name}-%{version}.tar.gz
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         libosip2-4.1.0.patch
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         libosip2-4.1.0-pthread.patch
BuildRequires:  docbook2x
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is the GNU oSIP library. It has been designed to provide the
Internet community with a simple way to support the Session Initiation
Protocol. SIP is described in the RFC 3261, which is available at
http://www.ietf.org/rfc/rfc3261.txt.

%package devel
Summary:        Implementation of SIP--RFC 3261
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       glibc-devel
Provides:       libosip2:/usr/include/osip2/osip.h

%description devel
This is the GNU oSIP library. It has been designed to provide the
Internet community with a simple way to support the Session Initiation
Protocol. SIP is described in the RFC 3261, which is available at
http://www.ietf.org/rfc/rfc3261.txt.

%prep
%setup -q
%patch0
%patch1

%build
autoreconf -fiv
%configure \
  --enable-pthread \
  --enable-mt \
  --enable-sysv \
  --enable-gperf \
  --disable-static \
  --with-pic
make %{?_smp_mflags}

%install
%makeinstall
rm -f %{buildroot}%{_libdir}/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/osipparser2
%{_includedir}/osip2
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/libosip2.pc
%{_mandir}/man1/*

%changelog
* Sun May 25 2014 fisiu@opensuse.org
- Update to 4.1.0:
  * fix sdp re-allocation
  * increase max length size
  * osip_trace_initialize returns 0 if log are compiled.
  * timer e and timer g will use #define DEFAULT_T2 instead of 4000.
  * handle additionnal possible malloc failure.
  * fix compatibility with old UA for INVITE retransmission.
  * fix osip_sem_destroy leak on apple.
  * accept lowercase sip/2.0.
- Rebase libosip2-3.5.0.dif and rename to libosip2-4.1.0.patch.
- Rebase libosip2-3.5.0-pthread.patch and rename to libosip2-4.1.0-pthread.patch.
* Thu Jun 20 2013 fisiu@opensuse.org
- Update to 4.0.0:
  * reduce path len // remove path in front of logs.
  * accept only SIP/D.D format message.
  * fix bug when releasing request with missing major headers.
  * fix minor memory leak // remove limitation on fifo size.
  * use system independant time for osip_gettimeofday on unix platform.
  * To compile/use osip based application in multi threaded
    env, you don't need to define -DOSIP_MT any more. Instead,
    if you wish to disable the feature, you can compile with
  - DOSIP_MONOTHREAD.
  * A few other clean up were made inside osip to avoid any
    define to appear in include files. Also to avoid conflict,
    config.h has been renamed to osip-config.h.
- Patches updated.
- Spec cleanup.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Apr 26 2011 crrodriguez@opensuse.org
- fix botched pthread linkage,it is going to break sooner or later.
* Sun Jan 16 2011 seife+obs@b1-systems.com
- update to version 3.5.0
  * iphone with TCP/TLS background support.
  * a lot of minor change/fix/improvments, sorry for not being
    able to have an history here...
- libosip2 (3.4.0)
  * remove CRLF before parsing SIP message.
  * modification to allow non-blocking socket for reliable transport.
  * fix race condition for non-atomic incrementation operation.
  * osip_list improvements.
  * osip_list prototypes and warnings fix.
  * new osip_strcasestr method.
- libosip2 (3.3.0)
  * new APPLE native interface for semaphore
  * add relative time in log information on linux/windows
  * fix: unescape last uri parameters.
- libosip2 (3.2.0)
  * return new error code for all API.
* Mon Feb 25 2008 crrodriguez@suse.de
- remove libtool archive with empty dependency_libs and static libraries
- update to version 3.1.0
  * Windows Mobile 5/6 improvments.
  * allow uncompliant/IMS authentication headers.
  * fix when a space appear as the first char in body.
  * terminate body with '\0' after parsing (don't rely on this!)
* Tue Dec 18 2007 mskibbe@suse.de
- update to version 3.0.3 which include
  o initial support for rtems
  o initial support for ucos.
  o Fix memory leaks
  o fix 64-bit (amd64) issue with hash
  o parser speed improvements
  o add NULL checks
  o automatic check for reliable protocol SCTP and TLS
* Wed May 16 2007 ro@suse.de
- branch off devel package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Mar 22 2005 hvogel@suse.de
- use the linphone version of 2.2.0
- package pkgconfig file
* Tue Nov  9 2004 ro@suse.de
- update to 2.2.0
* Wed Jul 28 2004 ro@suse.de
- update to 2.1.0
* Tue Jan 13 2004 schwab@suse.de
- Remove old libtool macros.
* Mon Oct 20 2003 ro@suse.de
- don't build as root
* Thu Sep 25 2003 ro@suse.de
- package created version 2.0.3-cvs
